@@ -14,7 +14,7 @@ from ._settings import settings
 from ._settings_instance import InstanceSettings
 from ._settings_instance import instance_description as description
 from ._settings_load import load_instance_settings, setup_storage_root
-from ._settings_store import instance_settings_file
+from ._settings_store import current_instance_settings_file, instance_settings_file
 from ._setup_schema import load_schema, setup_schema
 from ._setup_storage import get_storage_region
 
@@ -55,16 +55,16 @@ def register(isettings, usettings):
     push_instance_if_not_exists(storage)
 
 
-def validate_schema_arg(schema: Optional[str] = None) -> Optional[str]:
+def validate_schema_arg(schema: Optional[str] = None) -> str:
     if schema is None:
-        return None
+        return ""
     validated_schema = []
     for module in known_schema_names:
         if module in schema:
             validated_schema.append(module)
     if len(validated_schema) == 0:
         raise RuntimeError(f"Unknown schema modules. Only know {known_schema_names}.")
-    return ", ".join(validated_schema)
+    return ",".join(validated_schema)
 
 
 def persist_check_reload_schema(isettings: InstanceSettings):
@@ -102,6 +102,14 @@ def load(instance_name: str, migrate: Optional[bool] = None) -> Optional[str]:
     return message
 
 
+def close() -> None:
+    """Close existing instance.
+
+    Returns `None` if succeeds, otherwise a string error code.
+    """
+    current_instance_settings_file.unlink()
+
+
 ERROR_SQLITE_CACHE = """
 Your cached local SQLite file still exists, while your cloud SQLite file was deleted.
 Please delete {} or add it to the cloud location.
@@ -111,7 +119,7 @@ Please delete {} or add it to the cloud location.
 @doc_args(
     description.storage_root,
     description._dbconfig,
-    description.schema_modules,
+    description._schema,
 )
 def init(
     *,
@@ -135,7 +143,7 @@ def init(
         storage_root=storage_root,
         storage_region=get_storage_region(storage_root),
         _dbconfig=dbconfig,
-        schema_modules=validate_schema_arg(schema),
+        _schema=validate_schema_arg(schema),
     )
     persist_check_reload_schema(isettings)
     if instance_exists(isettings):
